"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_extra_1 = require("fs-extra");
const FUNCTION_NAME = 'metadata';
const generateFunctions = async ({ dest, netlifyConfig, versions, }) => {
    const src = (0, path_1.join)(__dirname, 'templates', `${FUNCTION_NAME}.js`);
    await (0, fs_extra_1.ensureDir)(dest);
    await (0, fs_extra_1.writeJson)((0, path_1.join)(dest, `${FUNCTION_NAME}.json`), { versions });
    await (0, fs_extra_1.copyFile)(src, (0, path_1.join)(dest, 'index.js'));
    netlifyConfig.functions[FUNCTION_NAME] = { node_bundler: 'esbuild' };
};
const getVersions = (packageJson) => {
    const { version } = packageJson;
    const url = process.env.URL;
    if (!version || !url)
        return null;
    return { [`v${version}`]: url };
};
const plugin = {
    async onBuild({ constants: { FUNCTIONS_SRC = 'netlify/functions' }, netlifyConfig, packageJson, }) {
        // Get versions
        const versions = getVersions(packageJson);
        if (!versions)
            return;
        // Add functions
        await generateFunctions({
            dest: (0, path_1.join)(FUNCTIONS_SRC, FUNCTION_NAME),
            netlifyConfig,
            versions,
        });
        // Add headers
        ['index', 'stories'].map((file) => netlifyConfig.headers.push({
            for: `/${file}.json`,
            values: {
                'Access-Control-Allow-Origin': '*',
                'Access-Control-Allow-Credentials': 'true',
            },
        }));
        // Add redirects
        netlifyConfig.redirects.push({
            from: `/${FUNCTION_NAME}.json`,
            to: `/.netlify/functions/${FUNCTION_NAME}`,
            status: 200,
        });
    },
};
module.exports = plugin;
